[![logo](https://www.hongsnet.net/images/logo.gif)](https://www.hongsnet.net)

# InfluxDB 설치 및 구성

> Time Series DBMS인 InfluxDB를 설치하고 구성하는데, OS는 CentOS 7 환경에서 진행한다.


# InfluxDB 설치 후 CLI 접속

```
# influx -username admin -password 패스워드
Connected to http://localhost:8086 version 1.8.10
InfluxDB shell version: 1.8.10
>
```

# InfluxDB DB 현황 확인

```
> show databases
name: databases
name
----
_internal
telegraf

> use telegraf
Using database telegraf

> show measurements
name: measurements
name
----
cpu
disk
diskio
kernel
mem
processes
swap
system
>
```
> InfluxDB는 RDBMS와 다르게 별도의 Table 및 제약조건에 대한 설계가 불필요 하다.


# InfluxDB YUM Repository 설정

> InfluxDB는 influxdata 회사에서 개발되고, 배포되는 솔루션이므로 다음과 같이 Repository를 생성해야 한다.

```
# cat /etc/yum.repos.d/influxdb.repo
[influxdb]
name = InfluxDB Repository - RHEL \$releasever
baseurl = https://repos.influxdata.com/rhel/\$releasever/\$basearch/stable
enabled = 1
gpgcheck = 1
gpgkey = https://repos.influxdata.com/influxdb.key
```

YUM Repository 설정 후 다음과 같이 패키지를 설치한다.

```
# yum install influxdb
```

InfluxDB RPM 패키지를 설치했으면, 다음과 같이 데몬 기동 및 활성화 한다.

```
# systemctl start influxdb; systemctl enable influxdb

```


# InfluxDB DB 생성 및 사용자 생성


1. 관리자(admin) 계정 생성

먼저, /etc/influxdb/influxdb.conf 설정 파일에 인증 설정이 적용되어 있으면, 작업이 불가능하기 때문에 다음과 같이 인증을 임시로 해제해야 한다.

```
# cat /etc/influxdb/influxdb.conf
...중략
[http]
...중략
auth-enabled = false

# systemctl restart influxdb

```

이제 인증이 비활성화 되었으므로, 다음과 같이 admin 계정을 생성한다.

```
# influx -precision rfc3339
...중략
> CREATE USER admin WITH PASSWORD 'solbox!wldnro7' WITH ALL PRIVILEGES
```

2. 데이터베이스 생성 

데이터베이스 생성은 RDBMS와 동일하게 **CREATE DATABASE** 명령을 사용한다.

```
> CREATE DATABASE hongsnet WITH DURATION 15d
> show databases;
name: databases
name
----
_internal
hongsnet
```

3. 일반 유저 생성

```
 CREATE USER hongsnet WITH PASSWORD 'ghdwngkselql'
> GRANT ALL ON hongsnet(DB명) TO hongsnet(사용자명)
```

만약 `해당 유저에 대해 admin 관리자를 포함한 모든 계정을 부여하고 싶다면`, 다음과 같이 **WITH ALL PRIVILEGES 권한을 부여**한다.

```
> CREATE USER hongsnet WITH PASSWORD 'ghdwngkselql' WITH ALL PRIVILEGES

```

4. InfluxDB 인증 재활성화

```
# cat /etc/influxdb/influxdb.conf
...중략
[http]
...중략
auth-enabled = true

# systemctl restart influxdb
```

