[![logo](https://www.hongsnet.net/images/logo.gif)](https://www.hongsnet.net)

# Pacemaker를 이용한 Zabbix 구성요소 이중화

> Zabbix 오픈소스 모니터링 솔루션을 운영 시 이중화를 통해 모니터링 서비스의 안정성을 강화한다.

# 구성 환경

- KVM Virtual Machine
- CentOS 7
- Pacemaker / Corosync
- Heartbeat Network
- Zabbix Proxy
- Zabbix Server


## Overview

![zabbix](./images/zabbix_ha.png)

### 장점
 - 오픈소스 솔루션이지만, `엔터프라이즈 급의 기능들을 제공`
 - 모니터링 요소는 템플릿 -> 아이템의 구조로 구성됨
 - 요소별 알람이 필요할 경우 트리거를 사용하여 구성됨
 - `Admin(Beginner) Level의 역랑`이면, 서버에 직접 아이템을 등록하여 모니터링할 수 있음
 - 아이템 별 그래프를 쉽게 생성할 수 있음
 - 스크린, 맵을 이용하여, 실시간 모니터링 또는 이를 시각화는 것이 가능

### 단점
 - `Proxy와 Server가 1:1로만 구성`되기 때문에 이중화/확장을 위해서는 인프라 요소가 다른 솔루션보다 상대적으로 많이 필요
   - 즉, `Proxy - Server - DBMS` 구성으로 하나의 POD가 되는 구조가 Best


## Zabbix Server 설치

1. Zabbix YUM Repository 설치

```bash
# rpm -Uvh https://repo.zabbix.com/zabbix/5.0/rhel/7/x86_64/zabbix-release-5.0-1.el7.noarch.rpm
```

2. Zabbix Server 및 Agent 설치

```bash
# yum install zabbix-server-mysql zabbix-agent
``` 

3. WEB U/I 설치

```bash
# yum install zabbix-web-mysql-scl zabbix-apache-conf-scl mariadb-server mod_ssl
```

4. DB 설치

상기 구성도는 외부의 DBMS로 되어있기 때문에 아래는 Local 에서 설치하는 것으로 대체한다.

```bash
# systemctl start mariadb; systemctl enable mariadb
```

다음과 같이 DBMS의 root 패스워드를 입력한다.

```bash
# mysql -u root -p
Enter password: 그냥 엔터
Welcome to the MariaDB monitor.  Commands end with ; or \g.
Your MariaDB connection id is 3
Server version: 5.5.68-MariaDB MariaDB Server
 
Copyright (c) 2000, 2018, Oracle, MariaDB Corporation Ab and others.
 
Type 'help;' or '\h' for help. Type '\c' to clear the current input statement.
 
MariaDB [(none)]>
```
먼저 다음과 같이 root 패스워드를 설정해 준다.

```bash
MariaDB [(none)]> use mysql;
MariaDB [mysql]> update user set password=password('디비루트패스워드') where user = 'root';
MariaDB [mysql]> flush privileges;
```

이제 최종적으로 zabbix 사용자에 대한 디비 작업을 진행 한다.

```bash
MariaDB [mysql]> create database zabbix character set utf8 collate utf8_bin;
MariaDB [mysql]> create user zabbix@localhost identified by '디비루트패스워드';
MariaDB [mysql]> grant all privileges on zabbix.* to zabbix@localhost;
```
기본적으로 제공하는 스키마를 MariaDB에 적용하면 된다.

```bash
# zcat /usr/share/doc/zabbix-server-mysql-5.0.30/create.sql.gz | mysql -u zabbix -p zabbix
Enter password:
...처리가 완료되면, 프롬프트가 그냥 떨어지게 된다.
```

위에서 설정된 DB 정보를 Zabbix 설정 파일에 적용한다.

```bash
# cat /etc/zabbix/zabbix_server.conf |grep DBPass
### Option: DBPassword
DBPassword=디비패스워드
```

마지막으로 Zabbix Server를 시작하고, 활성화 한다.

```bash
# systemctl start zabbix-server; systemctl enable zabbix-server
Created symlink from /etc/systemd/system/multi-user.target.wants/zabbix-server.service to /usr/lib/systemd/system/zabbix-server.service.
```

## Zabbix Proxy 설치

> Zabbix Proxy도 Server와 같이 Proxy와 DBMS으로 구성되기 때문에 DB가 별도로 구성되기 때문에 Server 쪽의 DB 구성과 같다.

다음과 같이 패키지를 설치한다.

```bash
# rpm -ivh https://repo.zabbix.com/zabbix/5.0/rhel/7/x86_64/zabbix-release-5.0-1.el7.noarch.rpm
# yum install mariadb mariadb-devel mariadb-server
 
# systemctl enable mariadb.service
# systemctl start mariadb.service
 
# yum install zabbix-agent zabbix-proxy-mysql
 
# mysql_secure_installation
 
# mysql -u root -p
 
MariaDB [(none)]> create database zabbix_proxy character set utf8 collate utf8_bin;
MariaDB [(none)]> grant all privileges on zabbix_proxy.* to zabbix@localhost identified by '패스워드';
MariaDB [(none)]> exit;
 
# zcat /usr/share/doc/zabbix-proxy-mysql-5.0.31/schema.sql.gz | mysql -u zabbix -p zabbix_proxy
Enter password:
 
# cat /etc/zabbix/zabbix_proxy.conf
...
LogFileSize=14
...
Server=zabbix의 서버IP
...
Hostname=zabbix-proxy.hongsnet.net <- 반드시 /etc/hosts 또는 DNS에 등록된 이름을 지정해야 한다. 아니면, 수집불가에러가 발생된다.
...
DBName=zabbix_proxy
...
DBUser=zabbix
...
DBPassword=ghdwngkselql
 
# systemctl enable zabbix-proxy.service
# systemctl start zabbix-proxy.service
```

> 아래의 프록시 설정은 Ansible을 통해 자동화 할 수 있기 때문에 "자동화" Article를 참조한다.


1. 관리 -> 프록시 -> 프록시 작성 이동

![zabbix-proxy1](./images/zabbix_proxy1.png)


2. 호스트 -> 프록시에 의한 감시 설정

![zabbix-proxy2](./images/zabbix_proxy2.png)


3. 설정완료 후 현황 확인

![zabbix-proxy3](./images/zabbix_proxy3.png)


## Pacemaker 설치 및 구성

Pacemaker는 Heartbeat Network으로 구성되기 때문에 다음과 같이 `/etc/hosts` 파일에 IP를 설정한다.

```bash
# cat /etc/hosts

127.0.0.1   localhost localhost.localdomain localhost4 localhost4.localdomain4

::1         localhost localhost.localdomain localhost6 localhost6.localdomain6

172.16.0.211 zabbix211
172.16.0.217 zabbix217
```

1. 패키지 설치 및 기본구성

```bash
# yum install pcs fence-agents-all
# systemctl start pcsd; systemctl enable pcsd

# echo 패스워드 | passwd --stdin hacluster
# pcs cluster auth zabbix211 zabbix217

# pcs cluster setup --start --name ZABBIX zabbix211 zabbix217
# pcs cluster enable --all

# pcs property set stonith-enabled=false
# pcs property set no-quorum-policy=ignore
```

2. VIP 클러스터 리소소 구성

```bash
# pcs resource create PU-VIP IPaddr2 ip=61.100.0.244 cidr_netmask=32 nic=eth0 op monitor interval=10s timeout=30s on-fail=standby
# pcs resource create PR-VIP IPaddr2 ip=172.16.0.244 cidr_netmask=32 nic=eth1 op monitor interval=10s timeout=30s on-fail=standby
```

3. Zabbix Server 요소별 리소스 구성

```bash
# pcs resource create HTTPD systemd:httpd
# pcs resource create PHP-FPM systemd:rh-php72-php-fpm
# pcs resource create GRAFANA systemd:grafana-server
# pcs resource create ZABBIX systemd:zabbix-server
```
> GRAFANA는 Zabbix의 그래프 인터페이스를 개선하기 위한 연동이다. Grafana는 아주 훌륭한 그래프를 제공해 준다.

4. 클러스터 리소스의 순서 제약조건을 구성

```bash
# pcs constraint order start PU-VIP then start PR-VIP
# pcs constraint order start PR-VIP then start PHP-FPM
# pcs constraint order start PHP-FPM then start HTTPD
# pcs constraint order start HTTPD then start GRAFANA
# pcs constraint order start GRAFANA then start ZABBIX
```

5. 요소별 리소스가 위치하는 제약조건을 구성

```bash
# pcs constraint colocation add PU-VIP with PR-VIP
# pcs constraint colocation add PR-VIP with PHP-FPM
# pcs constraint colocation add PHP-FPM with HTTPD
# pcs constraint colocation add HTTPD with GRAFANA
# pcs constraint colocation add GRAFANA with ZABBIX
# pcs constraint location ZABBIX prefers zabbix211=100
```

!참고 : 다음은 Zabbix Proxy의 Pacemaker 구성내역이다.

```bash
# pcs resource create PU-VIP IPaddr2 ip=61.100.0.220 cidr_netmask=32 nic=eth0 op monitor interval=10s timeout=30s on-fail=standby
# pcs resource create PR-VIP IPaddr2 ip=172.16.0.220 cidr_netmask=32 nic=eth1 op monitor interval=10s timeout=30s on-fail=standby

# pcs resource create ZABBIX-PROXY systemd:zabbix-proxy
# pcs constraint order start PU-VIP then start PR-VIP
# pcs constraint order start PR-VIP then start ZABBIX-PROXY

# pcs constraint colocation add PU-VIP with PR-VIP
# pcs constraint colocation add PR-VIP with ZABBIX-PROXY
# pcs constraint location ZABBIX-PROXY prefers zabbix-proxy224=100
```



